/* Vk/VkConfig.h.  Generated automatically by configure.  */
/* Vk/VkConfig.h.in.  Generated automatically from configure.in by autoheader.  */
/**
 *
 *  This file represents the machine specific preprocessor
 * directives that are generated by the GNU autoconf
 * utility
 * 
 * Chris Toshok
 * Copyright (C) 1995
 * The Hungry Programmers, Inc
 * All Rights Reserved
 *
 **/

#ifndef VKCONFIG_H
#define VKCONFIG_H

/* Define if you have the ANSI C header files.  */
#define STDC_HEADERS 1

#endif // VKCONFIG_H
