/*****************************************************************
    ViewKlass - C++ framework library for Motif

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Copyright (C) 2001 John Lemcke
    jlemcke@bigfoot.com
*****************************************************************/

/**
 *
 * $Id: VkProgressDialog.h,v 1.2 2002/01/22 12:35:50 jostle Exp $
 *
 * This file contains the class definition for the 
 * VkProgressDialog class.
 * 
 *
 *
 **/

#ifndef VKPROGRESSDIALOG_H
#define VKPROGRESSDIALOG_H

#include <Vk/VkConfig.h>
#include <Vk/VkInterruptDialog.h>

class VkProgressDialog : public VkInterruptDialog {
  
 public:
  
    VkProgressDialog(const char *name, Boolean showCancel = True);
	virtual ~VkProgressDialog() {}

    virtual Widget createDialog(Widget parent);

    virtual const char *className() { return "VkProgressDialog"; }

	void setPercentDone(int percent);

 private:
	int _percentDone;

	Widget _progressScale;
};

extern VkProgressDialog* theProgressDialogInstance();
#define theProgressDialog theProgressDialogInstance()

#endif // VKPROGRESSDIALOG
