/*****************************************************************
    ViewKlass - C++ framework library for Motif

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Copyright (C) 2001 John Lemcke
    jlemcke@bigfoot.com
*****************************************************************/

/**
 *
 * $Id: VkPrefRadio.h,v 1.2 2002/01/22 12:36:56 jostle Exp $
 *
 * This file contains the class definition for
 * the preference dialog radio buttons
 *
 *
 *
 **/

#ifndef VKPREFRADIO_H
#define VKPREFRADIO_H

#include <Vk/VkConfig.h>
#include <Vk/VkPrefGroup.h>

class VkPrefRadio : public VkPrefGroup {

 public:
    VkPrefRadio(const char *name,
				Boolean horizOrientation = FALSE,
				Boolean noLabel = FALSE);

	virtual ~VkPrefRadio() {}
	
    virtual const char *className() { return "VkPrefRadio"; }

    VkPrefItemType type() { return PI_radio; }

	void instantiate(Widget parent);
	
 private:

};

#endif // VkPREFRADIO_H
